==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsolePluginSpecFluent<A extends ConsolePluginSpecFluent<A>> extends Fluent<A>{
  public String getDisplayName();
  public A withDisplayName(String displayName);
  public Boolean hasDisplayName();
  
  /**
   * This method has been deprecated, please use method buildProxy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsolePluginProxy getProxy();
  public ConsolePluginProxy buildProxy();
  public A withProxy(ConsolePluginProxy proxy);
  public Boolean hasProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> withNewProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> withNewProxyLike(ConsolePluginProxy item);
  public ConsolePluginSpecFluent.ProxyNested<A> editProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxyLike(ConsolePluginProxy item);
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsolePluginService getService();
  public ConsolePluginService buildService();
  public A withService(ConsolePluginService service);
  public Boolean hasService();
  public A withNewService(String basePath,String name,String namespace,Integer port);
  public ConsolePluginSpecFluent.ServiceNested<A> withNewService();
  public ConsolePluginSpecFluent.ServiceNested<A> withNewServiceLike(ConsolePluginService item);
  public ConsolePluginSpecFluent.ServiceNested<A> editService();
  public ConsolePluginSpecFluent.ServiceNested<A> editOrNewService();
  public ConsolePluginSpecFluent.ServiceNested<A> editOrNewServiceLike(ConsolePluginService item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ProxyNested<N> extends Nested<N>,ConsolePluginProxyFluent<ConsolePluginSpecFluent.ProxyNested<N>>{
    public N and();
    public N endProxy();
    
  }
  public interface ServiceNested<N> extends Nested<N>,ConsolePluginServiceFluent<ConsolePluginSpecFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginSpecFluent.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsolePluginSpecFluent<A extends ConsolePluginSpecFluent<A>> extends Fluent<A>{
  public String getDisplayName();
  public A withDisplayName(String displayName);
  public Boolean hasDisplayName();
  
  /**
   * This method has been deprecated, please use method buildProxy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsolePluginProxy getProxy();
  public ConsolePluginProxy buildProxy();
  public A withProxy(ConsolePluginProxy proxy);
  public Boolean hasProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> withNewProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> withNewProxyLike(ConsolePluginProxy item);
  public ConsolePluginSpecFluent.ProxyNested<A> editProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxy();
  public ConsolePluginSpecFluent.ProxyNested<A> editOrNewProxyLike(ConsolePluginProxy item);
  
  /**
   * This method has been deprecated, please use method buildService instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsolePluginService getService();
  public ConsolePluginService buildService();
  public A withService(ConsolePluginService service);
  public Boolean hasService();
  public A withNewService(String basePath,String name,String namespace,Integer port);
  public ConsolePluginSpecFluent.ServiceNested<A> withNewService();
  public ConsolePluginSpecFluent.ServiceNested<A> withNewServiceLike(ConsolePluginService item);
  public ConsolePluginSpecFluent.ServiceNested<A> editService();
  public ConsolePluginSpecFluent.ServiceNested<A> editOrNewService();
  public ConsolePluginSpecFluent.ServiceNested<A> editOrNewServiceLike(ConsolePluginService item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ProxyNested<N> extends Nested<N>,ConsolePluginProxyFluent<ConsolePluginSpecFluent.ProxyNested<N>>{
    public N and();
    public N endProxy();
    
  }
  public interface ServiceNested<N> extends Nested<N>,ConsolePluginServiceFluent<ConsolePluginSpecFluent.ServiceNested<N>>{
    public N and();
    public N endService();
    
  }
  
}
